==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/lineswidgetitem.h <==
#ifndef LINESWIDGETITEM_H
#define LINESWIDGETITEM_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qobject.h>

#include <klistview.h>
#include <klocale.h>

namespace SubtitleComposer
{
	class LinesWidget;

	class LinesWidgetItem : public QObject, public KListViewItem
	{
		Q_OBJECT

		public:

			LinesWidgetItem( SubtitleLine* line, LinesWidget* parent, LinesWidgetItem* after );
			virtual ~LinesWidgetItem();

			SubtitleLine* line();

			bool isPlaying();
			void setPlaying( bool playing );

			LinesWidgetItem* nextSiblingCasted();

			virtual int width( const QFontMetrics& fm, const QListView* lv, int c ) const;

		public slots:

			void updateNumber( unsigned number );

		protected slots:

			void updatePrimaryText( const QString& text );
			void updateSecondaryText( const QString& text );
			void updateShowTime( const Time& showTime );
			void updateHideTime( const Time& hideTime );
			void updateStyles( int styles );
			void updateErrors( int errors );
			void updateMark( bool marked );

		protected:

			virtual void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
			virtual void okRename( int column );
			virtual void cancelRename( int column );

			const QPixmap& markPixmap();
			const QPixmap& errorPixmap();

		protected:

			SubtitleLine* m_line;
			bool m_isPlaying;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/lineswidgetitem.h <==
#ifndef LINESWIDGETITEM_H
#define LINESWIDGETITEM_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qobject.h>

#include <klistview.h>
#include <klocale.h>

class QStyleSheet;

namespace SubtitleComposer
{
	class LinesWidget;

	class LinesWidgetItem : public QObject, public KListViewItem
	{
		Q_OBJECT

		public:

			LinesWidgetItem( SubtitleLine* line, LinesWidget* parent, LinesWidgetItem* after );
			virtual ~LinesWidgetItem();

			SubtitleLine* line();

			bool isPlaying();
			void setPlaying( bool playing );

			LinesWidgetItem* nextSiblingCasted();

			virtual int width( const QFontMetrics& fm, const QListView* lv, int c ) const;

		public slots:

			void updateNumber( unsigned number );

		protected slots:

			void updatePrimaryText( const SString& text );
			void updateSecondaryText( const SString& text );
			void updateShowTime( const Time& showTime );
			void updateHideTime( const Time& hideTime );
			void updateErrors( int errors );
			void updateMark( bool marked );

		protected:

			virtual void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
			virtual void okRename( int column );
			virtual void cancelRename( int column );

			static const QPixmap& markPixmap();
			static const QPixmap& errorPixmap();

			static QStyleSheet* styleSheet();

		protected:

			SubtitleLine* m_line;
			bool m_isPlaying;
	};
}

#endif
